Module beamlit.models.create_workspace_service_account_body
===========================================================

Classes
-------

`CreateWorkspaceServiceAccountBody(name: str, description: beamlit.types.Unset | str = <beamlit.types.Unset object>)`
:   Attributes:
        name (str): Service account name
        description (Union[Unset, str]): Service account description
    
    Method generated by attrs for class CreateWorkspaceServiceAccountBody.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `description: beamlit.types.Unset | str`
    :

    `name: str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :